pub struct RecoveryOutcome {
pub recovered: Vec<RecoveredRun>,
pub parent_run_id: Option<RunId>,
}Expand description
Result of the predecessor recovery sweep performed in the kernel constructor.
Fields
recovered: Vec<RecoveredRun>One entry per predecessor that was sealed by the sweep.
parent_run_id: Option<RunId>The id of the most-recently-crashed predecessor sealed as
RunStatus::CrashedRecovered, or None when no recoverable predecessor
existed (or every predecessor was quarantined).